using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using UnityEngine;
using UnityEngine.Events;

namespace MPP
{
    #region SyringeObjects
    internal class ClawPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(ClawPowerPoison);
        }
    }

    internal class ShockwavePowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(ShockwavePoison);
        }
    }

    internal class MagnetSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(MagneticPoison);
        }
    }

    internal class byebyeSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(byebyePoison);
        }
    }

    internal class MultiShifterSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(MultiShifterPoison);
        }
    }

    internal class molSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(molPoison);
        }
    }

    internal class GriderSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(GriderPoison);
        }
    }

    internal class LaserEyePowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(LaserEyePowerPoison);
        }
    }

    internal class HulkPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(HulkPowerPoison);
        }
    }

    internal class RegenerationPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(RegenerationPowerPoison);
        }
    }

    internal class LightningSyringe : OldSyringeBehaviour
    {
        private AudioSource aud;

        public override Type GetPoisonType()
        {
            return typeof(LightningSyringePoison);
        }

        private void Start()
        {
            this.aud = this.gameObject.AddComponent<AudioSource>();
            this.gameObject.AddComponent<AudioSourceTimeScaleBehaviour>();
            this.aud.clip = MPP.crackle;
            this.aud.loop = true;
            this.aud.volume = 0.5f;
            this.aud.rolloffMode = AudioRolloffMode.Logarithmic;
            this.aud.maxDistance = 5f;
            this.aud.Play();
        }

        public void Update()
        {
            if (UnityEngine.Random.value >= 0.99f)
            {
                SimpleLightningEmitterBehaviour.Instance.Emit(this.transform.position, UnityEngine.Random.insideUnitCircle, 0.4f, 0.3f, lent, new Color32(205, 205, 230, 255), LayerMask.GetMask(new string[] { "Bounds" }), 0f, 32);
                this.gameObject.GetComponent<PhysicalBehaviour>().PlayClipOnce(MPP.zap, 0.6f);
            }
        }

        private void lent(PhysicalBehaviour phys, Vector2 pos)
        {
        }
    }

    internal class AntiRegenerationPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(AntiRegenerationPowerPoison);
        }
    }

    internal class PowerRemoverSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(PowerRemoverPoison);
        }
    }

    internal class KineticGraspPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(KineticGraspPowerPoison);
        }
    }

    internal class RegenerationPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return float.PositiveInfinity;
            }
        }

        public override float Lifespan
        {
            get
            {
                return float.PositiveInfinity;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            if (!physicalBehaviour.GetComponent<RegenerationPower>())
            {
                physicalBehaviour.gameObject.AddComponent<RegenerationPower>();
            }
        }



    }

    internal class HumanTorchPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(HumanTorchPowerPoison);
        }
    }

    public class WebShootingPowerSyringe : OldSyringeBehaviour
    {

        public override Type GetPoisonType()
        {
            return typeof(WebShootingPowerPoison);
        }
    }

    internal class TeleportPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(TeleportPowerPoison);
        }
    }

    internal class ForceFieldPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(ForceFieldPowerPoison);
        }
    }

    internal class InvisiblePowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(InvisiblePowerPoison);
        }
    }

    internal class MetalPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(MetalPowerPoison);
        }
    }

    internal class WallStickingSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(WallStickPowerPoison);
        }
    }

    internal class HammerHandsPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(HammerHandsPowerPoison);
        }
    }

    internal class VenomSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(VenomPoison);
        }
    }

    internal class VenomPunchSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(VenomPunchPoison);
        }
    }

    internal class CarnageSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(CarnagePoison);
        }
    }

    internal class ShapeShifterSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(ShapeShifterPoison);
        }
    }

    internal class AntiSymbioteSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(AntiSybiotePoison);
        }
    }

    internal class SuperSerumSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(SuperSerumPoison);
        }
    }

    internal class ThorGodSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(ThorGodPoison);
        }
    }

    internal class SuspendPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(SuspendPowerPoison);
        }
    }

    internal class FastManPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(FastManPowerPoison);
        }
    }

    internal class NutWomanPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(NutWomanPowerPoison);
        }
    }

    internal class KineticBlastPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(KineticBlastPoison);
        }
    }

    internal class AstroBodyPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(AstroBodyPoison);
        }
    }

    internal class QuackPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(QuackPowerPoison);
        }
    }
    
    internal class ShrinkerPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(ShrinkerPowerPoison);
        }
    }

    internal class SleepingTouchPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(SleepingTouchPowerPoison);
        }
    }

    internal class PhotonEnergyPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(PhotonEnergyPowerPoison);
        }
    }

    internal class SuperPunchPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(SuperPunchPowerPoison);
        }
    }

    internal class MysterioPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(MysterioPowerPoison);
        }
    }

    internal class EmpPowerSyringe : OldSyringeBehaviour
    {
        public override Type GetPoisonType()
        {
            return typeof(EmpPowerPoison);
        }
    }





    #endregion

    public class ClawPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 2;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour body = this.Limb.PhysicalBehaviour;
            GameObject Instance = body.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = body.GetComponent<LimbBehaviour>().Person;
            Sprite WeaponSprite = GameObject.FindObjectOfType<ClawPowerSyringe>().GetComponent<ResourceStorage>().sprites[0];
            string OriginalItem = "Knife";
            bool RedoCollisions = false;
            bool SmoothScale = false; ;
            if (!GetComponent<SlideableHandWeapon>())
            {
                if (GetComponent<GripBehaviour>())
                {
                    GameObject NewClaw = GameObject.Instantiate(ModAPI.FindSpawnable(OriginalItem).Prefab);
                    NewClaw.transform.SetParent(body.transform);
                    if (Instance.transform.localScale.x < 0)
                        NewClaw.transform.localScale = new Vector3(-NewClaw.transform.localScale.x, NewClaw.transform.localScale.y, NewClaw.transform.localScale.z);
                    NewClaw.GetComponent<SpriteRenderer>().sprite = WeaponSprite;//get the SpriteRenderer and replace its sprite with a custom one          
                    if (RedoCollisions)
                    {
                        NewClaw.FixColliders();
                    }
                    NewClaw.transform.position = body.transform.position;

                    NewClaw.transform.eulerAngles = new Vector3(NewClaw.transform.eulerAngles.x, NewClaw.transform.eulerAngles.y, NewClaw.transform.eulerAngles.z + 180);
                    foreach (var limbs in person.Limbs)
                        Physics2D.IgnoreCollision(limbs.GetComponent<Collider2D>(), NewClaw.GetComponent<Collider2D>());
                    foreach (var limbs in person.Limbs)
                    {
                        if (limbs.GetComponent<SlideableHandWeapon>())
                            Physics2D.IgnoreCollision(limbs.GetComponent<SlideableHandWeapon>().Claw.GetComponent<Collider2D>(), NewClaw.GetComponent<Collider2D>());
                    }
                    body.gameObject.AddComponent<FixedJoint2D>().connectedBody = NewClaw.GetComponent<Rigidbody2D>();
                    body.gameObject.AddComponent<SlideableHandWeapon>().SetUpClaw(body.gameObject, NewClaw);
                    body.gameObject.GetComponent<SlideableHandWeapon>().SlideOutSound = GameObject.FindObjectOfType<ClawPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[0];
                    body.gameObject.GetComponent<SlideableHandWeapon>().SlideInSound = GameObject.FindObjectOfType<ClawPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[1];
                    body.gameObject.GetComponent<SlideableHandWeapon>().OgGripPos = body.gameObject.GetComponent<GripBehaviour>().GripPosition;
                    body.gameObject.GetComponent<SlideableHandWeapon>().Scale = SmoothScale;
                    body.gameObject.GetComponent<GripBehaviour>().GripPosition = Vector3.one * 1000;
                    body.gameObject.GetComponent<SlideableHandWeapon>().PowerName = "Wolverine Claws";
                    body.gameObject.GetComponent<SlideableHandWeapon>().PowerIconId = 2;
                    body.gameObject.AddComponent<UseEventTrigger>().Action = () =>
                    {
                        body.gameObject.GetComponent<SlideableHandWeapon>().ToggleClaw();
                    };
                }
            }
        }




    }

    public class PhotonEnergyPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            //     if (!physicalBehaviour.GetComponent<SuperPowerMarvelPack>() || (physicalBehaviour.GetComponent<SuperPowerMarvelPack>() && physicalBehaviour.GetComponent<SuperPowerMarvelPack>().CanConsider))
            {
                if (physicalBehaviour.GetComponent<LimbBehaviour>().HasBrain)
                {
                    foreach (var body in person.Limbs)
                    {
                        SuperPowerSetups.SetFlying(body, person, Instance, "Captain Marvel");

                        body.RegenerationSpeed *= 110;
                        body.InitialHealth *= 200;
                        body.Health *= 200;
                        body.BreakingThreshold *= 120;
                        body.CirculationBehaviour.BleedingRate /= 7;

                    }

                    if (!person.Limbs[11].gameObject.GetComponent<ContinuousLaser>())
                    {
                        person.Limbs[11].gameObject.AddComponent<ContinuousLaser>().LaserTexture = GameObject.FindObjectOfType<PhotonEnergyPowerSyringe>().GetComponent<ResourceStorage>().textures[0];
                        person.Limbs[11].gameObject.GetComponent<ContinuousLaser>().LaserBeamSound = GameObject.FindObjectOfType<PhotonEnergyPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[0];
                    }
                    if (!person.Limbs[13].gameObject.GetComponent<ContinuousLaser>())
                    {
                        person.Limbs[13].gameObject.AddComponent<ContinuousLaser>().LaserTexture = GameObject.FindObjectOfType<PhotonEnergyPowerSyringe>().GetComponent<ResourceStorage>().textures[0];
                        person.Limbs[13].gameObject.GetComponent<ContinuousLaser>().LaserBeamSound = GameObject.FindObjectOfType<PhotonEnergyPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[0];
                    }

                }
            }
            //    else Component.Destroy(this);
        }



    }

    public class MysterioPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            //     if (!physicalBehaviour.GetComponent<SuperPowerMarvelPack>() || (physicalBehaviour.GetComponent<SuperPowerMarvelPack>() && physicalBehaviour.GetComponent<SuperPowerMarvelPack>().CanConsider))
            {
                if (physicalBehaviour.GetComponent<LimbBehaviour>().HasBrain)
                {
                    
                    if (!person.Limbs[11].gameObject.GetComponent<ContinuousLaser>())
                    {
                        person.Limbs[11].gameObject.AddComponent<ContinuousLaser>().LaserTexture = GameObject.FindObjectOfType<MysterioPowerSyringe>().GetComponent<ResourceStorage>().textures[0];
                        person.Limbs[11].gameObject.GetComponent<ContinuousLaser>().LaserBeamSound = GameObject.FindObjectOfType<MysterioPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[0];
                        person.Limbs[11].gameObject.GetComponent<ContinuousLaser>().Tint = Color.green;
                        person.Limbs[11].gameObject.GetComponent<ContinuousLaser>().Smokey = true;
                        person.Limbs[11].gameObject.GetComponent<ContinuousLaser>().PowerName = "Laser Beam";
                    }
                    if (!person.Limbs[13].gameObject.GetComponent<ContinuousLaser>())
                    {
                        person.Limbs[13].gameObject.AddComponent<ContinuousLaser>().LaserTexture = GameObject.FindObjectOfType<MysterioPowerSyringe>().GetComponent<ResourceStorage>().textures[0];
                        person.Limbs[13].gameObject.GetComponent<ContinuousLaser>().LaserBeamSound = GameObject.FindObjectOfType<MysterioPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[0];
                        person.Limbs[13].gameObject.GetComponent<ContinuousLaser>().Tint = Color.green;
                        person.Limbs[13].gameObject.GetComponent<ContinuousLaser>().Smokey = true;
                        person.Limbs[13].gameObject.GetComponent<ContinuousLaser>().PowerName = "Laser Beam";
                    }

                    if (!person.Limbs[0].gameObject.GetComponent<ClonePower>())
                    {
                        SuperPowerSetups.SetClonePower(person, person.gameObject);
                    }

                }
            }
            //    else Component.Destroy(this);
        }



    }

    public class EmpPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            //     if (!physicalBehaviour.GetComponent<SuperPowerMarvelPack>() || (physicalBehaviour.GetComponent<SuperPowerMarvelPack>() && physicalBehaviour.GetComponent<SuperPowerMarvelPack>().CanConsider))
            {
                if (physicalBehaviour.GetComponent<LimbBehaviour>().HasBrain)
                {      

                    if (!person.Limbs[1].gameObject.GetComponent<ElectroEMP>())
                    {
                        person.Limbs[1].gameObject.AddComponent<ElectroEMP>();
                    }

                }
            }
            //    else Component.Destroy(this);
        }



    }

    public class LaserEyePowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            //     if (!physicalBehaviour.GetComponent<SuperPowerMarvelPack>() || (physicalBehaviour.GetComponent<SuperPowerMarvelPack>() && physicalBehaviour.GetComponent<SuperPowerMarvelPack>().CanConsider))
            {
                if (physicalBehaviour.GetComponent<LimbBehaviour>().HasBrain)
                {
                    physicalBehaviour.gameObject.AddComponent<LaserEyes>();
                    physicalBehaviour.gameObject.GetComponent<LaserEyes>().LaserSound = GameObject.FindObjectOfType<LaserEyePowerSyringe>().GetComponent<ResourceStorage>().WebSounds[0];
                    physicalBehaviour.gameObject.GetComponent<LaserEyes>().body = physicalBehaviour.GetComponent<LimbBehaviour>();
                    physicalBehaviour.gameObject.AddComponent<UseEventTrigger>().Action = () =>
                    {
                        physicalBehaviour.gameObject.GetComponent<LaserEyes>().ShootLazer();
                    };

                }
            }
            //    else Component.Destroy(this);
        }



    }

    public class SuperPunchPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;


            if (!person.Limbs[11].gameObject.GetComponent<BigPunch>())
                person.Limbs[11].gameObject.AddComponent<BigPunch>();
            if (!person.Limbs[13].gameObject.GetComponent<BigPunch>())
                person.Limbs[13].gameObject.AddComponent<BigPunch>();
        }



    }

    public class SleepingTouchPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            if(!person.Limbs[11].gameObject.GetComponent<SleepHit>())
                person.Limbs[11].gameObject.AddComponent<SleepHit>();
            if (!person.Limbs[13].gameObject.GetComponent<SleepHit>())
                person.Limbs[13].gameObject.AddComponent<SleepHit>();


        }



    }

    public class ShrinkerPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            //     if (!physicalBehaviour.GetComponent<SuperPowerMarvelPack>() || (physicalBehaviour.GetComponent<SuperPowerMarvelPack>() && physicalBehaviour.GetComponent<SuperPowerMarvelPack>().CanConsider))
            {
                if (physicalBehaviour.GetComponent<LimbBehaviour>().Person.Limbs[13] && !physicalBehaviour.GetComponent<LimbBehaviour>().Person.Limbs[13].GetComponent<Shrinker>())
                {

                    LimbBehaviour body = physicalBehaviour.GetComponent<LimbBehaviour>().Person.Limbs[11];
                    body.gameObject.AddComponent<Shrinker>();
                    body.gameObject.GetComponent<Shrinker>().ChangeSizeSound = GameObject.FindObjectOfType<ShrinkerPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[0];
                    body.gameObject.GetComponent<Shrinker>().NormalSizeSound = GameObject.FindObjectOfType<ShrinkerPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[1];
                    ContextMenuButton ShrinkSize = new ContextMenuButton("Size", "Set shrink/grow size", "Set shrink/grow size", new UnityAction[1]
        {
            (UnityAction) (() =>
        {
            GameObject Canvas = OtherStuff.CreateCanvas();
            float defaultSize =  body.GetComponent<Shrinker>().TransformAmount;
            if (Canvas)
            {
                DialogBox dialog = (DialogBox)null;
          dialog = DialogBoxManager.TextEntry($"Set shrink/grow size", "default is 0.3. current is " + defaultSize + ".", new DialogButton("Accept", true, new UnityAction[1]
            {
                (UnityAction) (() =>
                {
                    if (dialog.EnteredText != "")
                    {;
                     int NewValue;
                        int.TryParse(dialog.EnteredText,out NewValue);
                        if(NewValue >  body.GetComponent<Shrinker>().MaxGrowth)
                           body.GetComponent<Shrinker>().TransformAmount = body.GetComponent<Shrinker>().MaxGrowth;
                        else if(NewValue <  body.GetComponent<Shrinker>().MinShrink)
                            body.GetComponent<Shrinker>().TransformAmount = body.GetComponent<Shrinker>().MinShrink;
                        else
                             body.GetComponent<Shrinker>().TransformAmount = NewValue;
                        Destroy(Canvas);
    {

    }
                    }
                })
            }),
            new DialogButton("Cancel", true, new UnityAction[1]
            {
                    (UnityAction) (() => {dialog.Close(); Destroy(Canvas);})
            }));
            }
                })});
                    body.gameObject.GetComponent<PhysicalBehaviour>().ContextMenuOptions.Buttons.Add(ShrinkSize);
                    body.gameObject.AddComponent<UseEventTrigger>().Action = () =>
                    {
                        body.gameObject.GetComponent<Shrinker>().Use();
                    };
                }
            }
            //    else Component.Destroy(this);
        }



    }

    public class PowerRemoverPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            foreach (var item in GetComponents<SuperPowerMarvelPack>())
            {
                item.RemovePower(true);
            }
            StartCoroutine(EndTimer());
        }

        private IEnumerator EndTimer()
        {
            yield return new WaitForSeconds(0.1f);
            Component.Destroy(this);

        }



    }
    
    public class HulkPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            {
                bool Good = true;
                foreach (var item in person.Limbs)
                {
                    if (item.GetComponent<Hulk>())
                    {
                        Good = false;
                        break;
                    }
                        
                }             
                if(Good)
                    SuperPowerSetups.SetHulkPower(physicalBehaviour.GetComponent<LimbBehaviour>(), person, Instance, false);
            }

           
        }



    }

    public class KineticGraspPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            if (!GetComponent<KineticGrasp>())
            {
                if (GetComponent<GripBehaviour>())
                {
                    gameObject.AddComponent<KineticGrasp>();
                }
            }
        }


    }

    public class AntiRegenerationPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            if (physicalBehaviour.GetComponent<RegenerationPower>())
            {
                Component.Destroy(physicalBehaviour.GetComponent<RegenerationPower>());
            }
        }



    }
    
    public class ShockwavePoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;

            if (!person.Limbs[11].gameObject.GetComponent<Shocker>())
            {
                person.Limbs[11].gameObject.AddComponent<Shocker>();
            }
            
            if (!person.Limbs[13].gameObject.GetComponent<Shocker>())
            {
                person.Limbs[13].gameObject.AddComponent<Shocker>();
            }
        }
    }

    public class MagneticPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;

            if (!person.Limbs[11].gameObject.GetComponent<biden>())
            {
                person.Limbs[11].gameObject.AddComponent<biden>();
            }
            
            if (!person.Limbs[13].gameObject.GetComponent<biden>())
            {
                person.Limbs[13].gameObject.AddComponent<biden>();
            }
        }
    }

    public class byebyePoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;

            if (!person.Limbs[11].gameObject.GetComponent<PowerStealer>())
            {
                person.Limbs[11].gameObject.AddComponent<PowerStealer>();
            }
            
            if (!person.Limbs[13].gameObject.GetComponent<PowerStealer>())
            {
                person.Limbs[13].gameObject.AddComponent<PowerStealer>();
            }
        }
    }

    public class molPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;

            if (!person.Limbs[11].gameObject.GetComponent<diediedie>())
            {
                person.Limbs[11].gameObject.AddComponent<diediedie>();
            }
            
            if (!person.Limbs[13].gameObject.GetComponent<diediedie>())
            {
                person.Limbs[13].gameObject.AddComponent<diediedie>();
            }
        }
    }

    public class GriderPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;

            if (!person.Limbs[0].gameObject.GetComponent<despair>())
            {
                person.Limbs[0].gameObject.AddComponent<despair>();
            }
       
        }
    }

    public class LightningSyringePoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            if (this.Limb != null)
            {
                if (this.Limb.gameObject.name.Contains("LowerArm"))
                {
                    this.Limb.gameObject.GetOrAddComponent<ElectroLightning>();
                }
                this.Limb.PhysicalBehaviour.ForceNoCharge = true;
            }
        }
    }

    public class HumanTorchPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            //     if (!physicalBehaviour.GetComponent<SuperPowerMarvelPack>() || (physicalBehaviour.GetComponent<SuperPowerMarvelPack>() && physicalBehaviour.GetComponent<SuperPowerMarvelPack>().CanConsider))
            {
                if (!physicalBehaviour.GetComponent<HumanTorch>())
                {
                    SuperPowerSetups.SetPeopleTorchPower(physicalBehaviour.GetComponent<LimbBehaviour>(), person, Instance.gameObject,false);

                }
            }
            //    else Component.Destroy(this);
        }



    }

    public class WebShootingPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
           
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            if (!physicalBehaviour.GetComponent<WebSlinging>() && physicalBehaviour.GetComponent<GripBehaviour>())
            {
                    SuperPowerSetups.SetTaserWebPower(physicalBehaviour.GetComponent<LimbBehaviour>(), person, Instance, GameObject.FindObjectOfType<WebShootingPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[0], GameObject.FindObjectOfType<WebShootingPowerSyringe>().GetComponent<ResourceStorage>().sprites[0]);
                    SuperPowerSetups.SetWebTetherPower(physicalBehaviour.GetComponent<LimbBehaviour>(), person, Instance, GameObject.FindObjectOfType<WebShootingPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[0],GameObject.FindObjectOfType<WebShootingPowerSyringe>().GetComponent<ResourceStorage>().sprites[0]);
                    SuperPowerSetups.SetMultiWebPower(physicalBehaviour.GetComponent<LimbBehaviour>(), person, Instance, GameObject.FindObjectOfType<WebShootingPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[0], GameObject.FindObjectOfType<WebShootingPowerSyringe>().GetComponent<ResourceStorage>().sprites[0]);

                physicalBehaviour.gameObject.AddComponent<WebSlinging>().IsSyringed = true;
                physicalBehaviour.gameObject.GetComponent<WebSlinging>().WebShootSound = GameObject.FindObjectOfType<WebShootingPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[0];
                physicalBehaviour.gameObject.GetComponent<WebSlinging>().sprite = GameObject.FindObjectOfType<WebShootingPowerSyringe>().GetComponent<ResourceStorage>().sprites[0];
                physicalBehaviour.gameObject.GetComponent<WebSlinging>().OgGripPos = physicalBehaviour.GetComponent<LimbBehaviour>().gameObject.GetComponent<GripBehaviour>().GripPosition;
                physicalBehaviour.gameObject.GetComponent<GripBehaviour>().GripPosition = Vector3.one * 1000;
                physicalBehaviour.gameObject.GetComponent<WebSlinging>().body = physicalBehaviour.GetComponent<LimbBehaviour>();
                physicalBehaviour.gameObject.AddComponent<UseEventTrigger>().Action = () =>
                {
                    physicalBehaviour.gameObject.GetComponent<WebSlinging>().ShootWeb();
                };
            }
        }



    }

    public class TeleportPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            if (!physicalBehaviour.GetComponent<TeleportForward>())
                SuperPowerSetups.SetTeleportPower(physicalBehaviour.GetComponent<LimbBehaviour>(), person, Instance.gameObject);
        }



    }

    public class ForceFieldPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            if (physicalBehaviour.GetComponent<LimbBehaviour>().GetComponent<GripBehaviour>())
            {
                if (!physicalBehaviour.GetComponent<ForceFieldShield>())
                {
                    SuperPowerSetups.SetForceFieldPower(physicalBehaviour.GetComponent<LimbBehaviour>(), person, Instance.gameObject, true);
                    physicalBehaviour.GetComponent<ForceFieldShield>().Form = GameObject.FindObjectOfType<ForceFieldPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[0];
                    physicalBehaviour.GetComponent<ForceFieldShield>().Amb = GameObject.FindObjectOfType<ForceFieldPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[1];
                    physicalBehaviour.GetComponent<ForceFieldShield>().Deform = GameObject.FindObjectOfType<ForceFieldPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[2];
                    physicalBehaviour.GetComponent<ForceFieldShield>().ShieldSprite = GameObject.FindObjectOfType<ForceFieldPowerSyringe>().GetComponent<ResourceStorage>().sprites[0];
                }
            }
                    
        }



    }

    public class InvisiblePowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            if (!physicalBehaviour.GetComponent<Invisibility>())
                SuperPowerSetups.SetInvisiblilityPower(physicalBehaviour.GetComponent<LimbBehaviour>(), person, Instance.gameObject);
        }



    }

    public class MetalPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            if (!physicalBehaviour.GetComponent<MetalShifter>())
            {
                physicalBehaviour.gameObject.AddComponent<MetalShifter>().IsColossus = false;
                if (physicalBehaviour.GetComponent<LimbBehaviour>().HasBrain)
                {
                    physicalBehaviour.gameObject.AddComponent<UseEventTrigger>().Action = () =>
                    {
                        foreach (var item in person.Limbs)
                        {
                            item.GetComponent<MetalShifter>().ToggleMetal();
                        }
                    };
                }
            }
        }



    }

    public class WallStickPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 2;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            if (!GetComponent<WallSticking>())
            {
                SuperPowerSetups.SetWallStickingPower(physicalBehaviour.GetComponent<LimbBehaviour>(), physicalBehaviour.GetComponent<LimbBehaviour>().Person, physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject);
            }
        }




    }

    public class HammerHandsPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 2;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour body = this.Limb.PhysicalBehaviour;
            GameObject Instance = body.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = body.GetComponent<LimbBehaviour>().Person;
            Sprite WeaponSprite = GameObject.FindObjectOfType<HammerHandsPowerSyringe>().GetComponent<ResourceStorage>().sprites[0];
            string OriginalItem = "Hammer";
            bool RedoCollisions = true;
            bool SmoothScale = true;
            if (!(GetComponent<SlideableHandWeapon>() && GetComponent<SlideableHandWeapon>().PowerName == "Hammer Hands"))
            {
                if (GetComponent<GripBehaviour>())
                {
                    GameObject NewClaw = GameObject.Instantiate(ModAPI.FindSpawnable(OriginalItem).Prefab);
                    NewClaw.transform.SetParent(body.transform);
                    if (Instance.transform.localScale.x < 0)
                        NewClaw.transform.localScale = new Vector3(-NewClaw.transform.localScale.x, NewClaw.transform.localScale.y, NewClaw.transform.localScale.z);
                    NewClaw.GetComponent<SpriteRenderer>().sprite = WeaponSprite;//get the SpriteRenderer and replace its sprite with a custom one          
                    if (RedoCollisions)
                    {
                        NewClaw.FixColliders();
                    }
                    NewClaw.transform.position = body.transform.position;

                    NewClaw.transform.eulerAngles = new Vector3(NewClaw.transform.eulerAngles.x, NewClaw.transform.eulerAngles.y, NewClaw.transform.eulerAngles.z + 180);
                    foreach (var limbs in person.Limbs)
                        Physics2D.IgnoreCollision(limbs.GetComponent<Collider2D>(), NewClaw.GetComponent<Collider2D>());
                    foreach (var limbs in person.Limbs)
                    {
                        if (limbs.GetComponent<SlideableHandWeapon>())
                            Physics2D.IgnoreCollision(limbs.GetComponent<SlideableHandWeapon>().Claw.GetComponent<Collider2D>(), NewClaw.GetComponent<Collider2D>());
                    }
                    body.gameObject.AddComponent<FixedJoint2D>().connectedBody = NewClaw.GetComponent<Rigidbody2D>();
                    body.gameObject.AddComponent<SlideableHandWeapon>().SetUpClaw(body.gameObject, NewClaw);
                    body.gameObject.GetComponent<SlideableHandWeapon>().SlideOutSound = GameObject.FindObjectOfType<HammerHandsPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[0];
                    body.gameObject.GetComponent<SlideableHandWeapon>().SlideInSound = GameObject.FindObjectOfType<HammerHandsPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[1];
                    body.gameObject.GetComponent<SlideableHandWeapon>().OgGripPos = body.gameObject.GetComponent<GripBehaviour>().GripPosition;
                    body.gameObject.GetComponent<SlideableHandWeapon>().Scale = SmoothScale;
                    body.gameObject.GetComponent<GripBehaviour>().GripPosition = Vector3.one * 1000;
                    body.gameObject.GetComponent<SlideableHandWeapon>().PowerName = "Hammer Hands";
                    body.gameObject.GetComponent<SlideableHandWeapon>().PowerIconId = 4;
                    body.gameObject.AddComponent<UseEventTrigger>().Action = () =>
                    {
                        body.gameObject.GetComponent<SlideableHandWeapon>().ToggleClaw();
                    };
                }
            }
        }




    }

    public class VenomPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 2;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            if (!GetComponent<Symbiote>())
            {
                gameObject.AddComponent<Symbiote>();
                foreach (var item in person.Limbs)
                {
                    if (item.HasBrain && !item.GetComponent<SwapSkinPerm>())
                    {
                        if (item.gameObject.GetComponent<SwapSkin>())
                            item.gameObject.GetComponent<SwapSkin>().CanUse = false;
                        item.gameObject.AddComponent<SwapSkinPerm>().DefaultSkin = GetComponent<LimbBehaviour>().SkinMaterialHandler.renderer.sprite.texture;
                        item.gameObject.GetComponent<SwapSkinPerm>().SwitcherSkin = GameObject.FindObjectOfType<VenomSyringe>().GetComponent<ResourceStorage>().sprites[1].texture;
                        item.gameObject.GetComponent<SwapSkinPerm>().SwitchSkin();
                    }
                }
                if (physicalBehaviour.GetComponent<GripBehaviour>())
                {
                    if (physicalBehaviour.gameObject.GetComponent<WebSlinging>())
                    {
                        physicalBehaviour.gameObject.GetComponent<Symbiote>().HadWebPowers = true;
                        physicalBehaviour.gameObject.GetComponent<Symbiote>().sprite = physicalBehaviour.gameObject.GetComponent<WebSlinging>().sprite;
                        physicalBehaviour.gameObject.GetComponent<Symbiote>().WebShootSound= physicalBehaviour.gameObject.GetComponent<WebSlinging>().WebShootSound;
                        physicalBehaviour.gameObject.GetComponent<WebSlinging>().sprite = GameObject.FindObjectOfType<VenomSyringe>().GetComponent<ResourceStorage>().sprites[0];
                    }
                        
                    else
                    {
                        physicalBehaviour.gameObject.AddComponent<WebSlinging>().IsSyringed = true;
                        physicalBehaviour.gameObject.GetComponent<WebSlinging>().WebShootSound = GameObject.FindObjectOfType<VenomSyringe>().GetComponent<ResourceStorage>().WebSounds[0];
                        physicalBehaviour.gameObject.GetComponent<WebSlinging>().sprite = GameObject.FindObjectOfType<VenomSyringe>().GetComponent<ResourceStorage>().sprites[0];
                        physicalBehaviour.gameObject.AddComponent<UseEventTrigger>().Action = () =>
                        {
                            physicalBehaviour.gameObject.GetComponent<WebSlinging>().ShootWeb();
                        };
                    }

                    physicalBehaviour.gameObject.GetComponent<WebSlinging>().OgGripPos = physicalBehaviour.GetComponent<LimbBehaviour>().gameObject.GetComponent<GripBehaviour>().GripPosition;
                    physicalBehaviour.gameObject.GetComponent<GripBehaviour>().GripPosition = Vector3.one * 1000;
                    physicalBehaviour.gameObject.GetComponent<WebSlinging>().body = physicalBehaviour.GetComponent<LimbBehaviour>();
                }
                if (!GetComponent<WallSticking>())
                {
                    SuperPowerSetups.SetWallStickingPower(physicalBehaviour.GetComponent<LimbBehaviour>(), physicalBehaviour.GetComponent<LimbBehaviour>().Person, physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject);
                }
                else GetComponent<Symbiote>().HadStickPowers = true;

            }
        }




    }

    public class VenomPunchPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 2;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            if (!GetComponent<StrongHit>())
            {
                SuperPowerSetups.SetStrongHitPower(physicalBehaviour.gameObject.GetComponent<LimbBehaviour>(), person, Instance, new Color32(220, 147, 2, 255));
            }
        }




    }

    public class MultiShifterPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 2;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
                SuperPowerSetups.SetMultiShifterPower2causeimkindadumb(physicalBehaviour.gameObject.GetComponent<LimbBehaviour>(), person, Instance);
        }




    }

    public class ShapeShifterPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 2;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;

            if (!GetComponent<TouchShapeShifter>())
            {
                if (physicalBehaviour.gameObject.GetComponent<SwapSkin>())
                {
                    if(physicalBehaviour.gameObject.GetComponent<SwapSkin>().IsTogged)
                        physicalBehaviour.gameObject.GetComponent<SwapSkin>().SwitchSkin();
                    physicalBehaviour.gameObject.GetComponent<SwapSkin>().CanUse = false;
                }
                SuperPowerSetups.SetShapeShifter(physicalBehaviour.gameObject.GetComponent<LimbBehaviour>(), person, Instance);
            }
        }




    }

    public class CarnagePoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 2;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            if (!GetComponent<Symbiote>())
            {
                gameObject.AddComponent<Symbiote>();
                foreach (var body in person.Limbs)
                {
                    if (body.HasBrain && !body.GetComponent<SwapSkinPerm>())
                    {
                        if (body.gameObject.GetComponent<SwapSkin>())
                            body.gameObject.GetComponent<SwapSkin>().CanUse = false;
                        body.gameObject.AddComponent<SwapSkinPerm>().DefaultSkin = GetComponent<LimbBehaviour>().SkinMaterialHandler.renderer.sprite.texture;
                        body.gameObject.GetComponent<SwapSkinPerm>().SwitcherSkin = GameObject.FindObjectOfType<CarnageSyringe>().GetComponent<ResourceStorage>().sprites[1].texture;
                        body.gameObject.GetComponent<SwapSkinPerm>().SwitchSkin();
                    }

                    if (body.GetComponent<GripBehaviour>())
                    {
                        if (!physicalBehaviour.GetComponent<WebSlinging>())
                        {
                            physicalBehaviour.gameObject.AddComponent<WebSlinging>().IsSyringed = true;
                            physicalBehaviour.gameObject.GetComponent<WebSlinging>().WebShootSound = GameObject.FindObjectOfType<CarnageSyringe>().GetComponent<ResourceStorage>().WebSounds[0];
                            physicalBehaviour.gameObject.GetComponent<WebSlinging>().sprite = GameObject.FindObjectOfType<CarnageSyringe>().GetComponent<ResourceStorage>().sprites[0];
                            physicalBehaviour.gameObject.GetComponent<WebSlinging>().OgGripPos = physicalBehaviour.GetComponent<LimbBehaviour>().gameObject.GetComponent<GripBehaviour>().GripPosition;
                            physicalBehaviour.gameObject.GetComponent<GripBehaviour>().GripPosition = Vector3.one * 1000;
                            physicalBehaviour.gameObject.GetComponent<WebSlinging>().body = physicalBehaviour.GetComponent<LimbBehaviour>();
                            physicalBehaviour.gameObject.AddComponent<UseEventTrigger>().Action = () =>
                            {
                                physicalBehaviour.gameObject.GetComponent<WebSlinging>().ShootWeb();
                            };
                        }


                        Sprite WeaponSprite = GameObject.FindObjectOfType<CarnageSyringe>().GetComponent<ResourceStorage>().sprites[2];
                        string OriginalItem = "Knife";
                        bool RedoCollisions = false;
                        bool SmoothScale = false; ;
                        GameObject NewClaw = GameObject.Instantiate(ModAPI.FindSpawnable(OriginalItem).Prefab);
                        NewClaw.transform.SetParent(body.transform);
                        if (Instance.transform.localScale.x < 0)
                            NewClaw.transform.localScale = new Vector3(-NewClaw.transform.localScale.x, NewClaw.transform.localScale.y, NewClaw.transform.localScale.z);
                        NewClaw.GetComponent<SpriteRenderer>().sprite = WeaponSprite;//get the SpriteRenderer and replace its sprite with a custom one          
                        if (RedoCollisions)
                        {
                            NewClaw.FixColliders();
                        }
                        NewClaw.transform.position = body.transform.position;

                        NewClaw.transform.eulerAngles = new Vector3(NewClaw.transform.eulerAngles.x, NewClaw.transform.eulerAngles.y, NewClaw.transform.eulerAngles.z + 180);
                        foreach (var limbs in person.Limbs)
                            Physics2D.IgnoreCollision(limbs.GetComponent<Collider2D>(), NewClaw.GetComponent<Collider2D>());
                        foreach (var limbs in person.Limbs)
                        {
                            if (limbs.GetComponent<SlideableHandWeapon>())
                                Physics2D.IgnoreCollision(limbs.GetComponent<SlideableHandWeapon>().Claw.GetComponent<Collider2D>(), NewClaw.GetComponent<Collider2D>());
                        }
                        body.gameObject.AddComponent<FixedJoint2D>().connectedBody = NewClaw.GetComponent<Rigidbody2D>();
                       
                        body.gameObject.GetComponent<GripBehaviour>().GripPosition = Vector3.one * 1000;
                        body.gameObject.AddComponent<UseEventTrigger>().Action = () =>
                        {
                            body.gameObject.GetComponent<SlideableHandWeapon>().ToggleClaw();
                        };

                    }


                }




            }
        }




    }

    public class SuperSerumPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 2;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            physicalBehaviour.GetComponent<LimbBehaviour>().RegenerationSpeed *= 100;
            physicalBehaviour.GetComponent<LimbBehaviour>().InitialHealth *= 100;
            physicalBehaviour.GetComponent<LimbBehaviour>().Health *= 100;
            physicalBehaviour.GetComponent<LimbBehaviour>().BreakingThreshold *= 100;
            physicalBehaviour.GetComponent<LimbBehaviour>().CirculationBehaviour.BleedingRate = physicalBehaviour.GetComponent<LimbBehaviour>().CirculationBehaviour.BleedingRate / 5;
        }




    }

    public class ThorGodPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 2;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            physicalBehaviour.GetComponent<LimbBehaviour>().RegenerationSpeed = 99999;
            physicalBehaviour.GetComponent<LimbBehaviour>().BreakingThreshold = 99999;
            physicalBehaviour.GetComponent<LimbBehaviour>().CirculationBehaviour.BleedingRate = 0;
            physicalBehaviour.GetComponent<LimbBehaviour>().PhysicalBehaviour.ConductOverride = false;
        }




    }

    public class AntiSybiotePoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 2;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            if (GetComponent<Symbiote>())
            {
                GetComponent<Symbiote>().RemovePower(false);
            }
        }




    }

    public class SuspendPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {

            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            if (!physicalBehaviour.GetComponent<SuspenderHand>() && GetComponent<GripBehaviour>())
            {
                physicalBehaviour.gameObject.AddComponent<SuspenderHand>().OgGripPos = physicalBehaviour.gameObject.GetComponent<GripBehaviour>().GripPosition;
                physicalBehaviour.gameObject.GetComponent<SuspenderHand>().SuspendSound = GameObject.FindObjectOfType<SuspendPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[0];
                physicalBehaviour.gameObject.GetComponent<SuspenderHand>().ShootSound = GameObject.FindObjectOfType<SuspendPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[1];
                physicalBehaviour.gameObject.GetComponent<SuspenderHand>().Particle = GameObject.FindObjectOfType<SuspendPowerSyringe>().GetComponent<ResourceStorage>().textures[0];
                physicalBehaviour.gameObject.AddComponent<UseEventTrigger>().Action = () =>
                {
                    physicalBehaviour.gameObject.GetComponent<SuspenderHand>().SuspendShoot();
                };


            }
        }



    }

    public class FastManPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {

            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            if (!physicalBehaviour.GetComponent<FastMan>())
            {
                SuperPowerSetups.SetFastManPower(physicalBehaviour.GetComponent<LimbBehaviour>(), person, Instance);
            }
            
        }



    }

    public class NutWomanPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {

            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;

            if (!physicalBehaviour.GetComponent<NutHands>())
            {
                var RatSprite = GameObject.FindObjectOfType<NutWomanPowerSyringe>().GetComponent<ResourceStorage>().sprites[0];
                List<AudioClip> RatNoises = new List<AudioClip>();
                RatNoises.Add(GameObject.FindObjectOfType<NutWomanPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[0]);
                RatNoises.Add(GameObject.FindObjectOfType<NutWomanPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[1]);
                RatNoises.Add(GameObject.FindObjectOfType<NutWomanPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[2]);
                RatNoises.Add(GameObject.FindObjectOfType<NutWomanPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[3]);
                RatNoises.Add(GameObject.FindObjectOfType<NutWomanPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[4]);
                RatNoises.Add(GameObject.FindObjectOfType<NutWomanPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[5]);
                SuperPowerSetups.SetNuttHands(physicalBehaviour.GetComponent<LimbBehaviour>(), physicalBehaviour.GetComponent<LimbBehaviour>().Person, physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject, RatNoises, RatSprite);
            }








        }


      
    }

    public class KineticBlastPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {

            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            if (physicalBehaviour.GetComponent<LimbBehaviour>().gameObject.name == "UpperBody" && !physicalBehaviour.GetComponent<LimbBehaviour>().GetComponent<KineticShieldBuild>())
            {
                SuperPowerSetups.SetKineticBlastPower(physicalBehaviour.GetComponent<LimbBehaviour>(), person, Instance,GameObject.FindObjectOfType<KineticBlastPowerSyringe>().GetComponent<ResourceStorage>().textures[0], GameObject.FindObjectOfType<KineticBlastPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[0]);
                physicalBehaviour.GetComponent<LimbBehaviour>().GetComponent<KineticShieldBuild>().PowerIconId = 18;

            }
        }



    }

    public class AstroBodyPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {

            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;
            if (physicalBehaviour.gameObject.name == "UpperBody" && !physicalBehaviour.gameObject.GetComponent<GoingGhost>() && !(physicalBehaviour.GetComponent<Identity>() && physicalBehaviour.GetComponent<Identity>().IdentityName == "Custom"))
            {
                physicalBehaviour.gameObject.AddComponent<GoingGhost>().skin = person.Limbs[0].SkinMaterialHandler.renderer.sprite.texture;
            }
        }



    }

    public class QuackPowerPoison : PoisonSpreadBehaviour
    {
        public LimbBehaviour limb;

        public override float SpreadSpeed
        {
            get
            {
                return 55;
            }
        }

        public override float Lifespan
        {
            get
            {
                return 1;
            }
        }

        public override void Start()
        {
            PhysicalBehaviour physicalBehaviour = this.Limb.PhysicalBehaviour;
            GameObject Instance = physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject;
            PersonBehaviour person = physicalBehaviour.GetComponent<LimbBehaviour>().Person;

            SuperPowerSetups.SetQuack(physicalBehaviour.GetComponent<LimbBehaviour>(), physicalBehaviour.GetComponent<LimbBehaviour>().Person, physicalBehaviour.GetComponent<LimbBehaviour>().Person.gameObject, GameObject.FindObjectOfType<QuackPowerSyringe>().GetComponent<ResourceStorage>().WebSounds[0]);
        }



    }
}    